==> jasperreports-server-cp-4.0.0-src.zip: jasperreports-server-cp-4.0.0-src/jasperserver/jasperserver-war-jar/src/main/java/com/jaspersoft/jasperserver/war/action/ReportInputControlsAction.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.jaspersoft.jasperserver.war.action;

import java.util.List;
import java.util.Map;

import org.springframework.webflow.execution.RequestContext;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: ReportInputControlsAction.java 19932 2010-12-11 15:24:29Z tmatyashovsky $
 */
public interface ReportInputControlsAction {

	Map getReportParameters(RequestContext context);
	
	String getReportURI(RequestContext context);
	
	List getInputControlWrappers(RequestContext context);
	
	void setParameterValues(RequestContext context, Map values);
	
	void resetValuesToDefaults(RequestContext context);
	
}

==> jasperreports-server-cp-5.1.0-src.zip: jasperreports-server-cp-5.1.0-src/jasperserver/jasperserver-war-jar/src/main/java/com/jaspersoft/jasperserver/war/action/ReportInputControlsAction.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

package com.jaspersoft.jasperserver.war.action;

import com.jaspersoft.jasperserver.war.cascade.CascadeResourceNotFoundException;
import org.springframework.webflow.execution.RequestContext;

import java.util.Map;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: ReportInputControlsAction.java 22842 2012-03-28 09:39:29Z afomin $
 */
public interface ReportInputControlsAction {

	/*Map getReportParameters(RequestContext context);*/
    public Map<String, Object> getReportParameterValuesFromRequest(RequestContext context) throws CascadeResourceNotFoundException;
	
	String getReportURI(RequestContext context);
	
	/*List getInputControlWrappers(RequestContext context);*/
	
	/*void setParameterValues(RequestContext context, Map values);*/
	
	/*void resetValuesToDefaults(RequestContext context);*/
	
}
